﻿// DlgMngFile.cpp : implemetation file
//

#include "stdafx.h"
#include "HRRpcCli.h"
#include "HResMsg.h"
#include "HRRpcCliDlg.h"
#include "ProgressShow.h"
#include "COM/Loose_COM.h"
#include "DlgMngFile.h"


using namespace std;


// function prototypes
CString LoadString(UINT nID);


// DlgMngFile dialog box

IMPLEMENT_DYNAMIC(DlgMngFile, CDialog)

// --------------------------------------------------------
/// @brief		constructor
// --------------------------------------------------------
DlgMngFile::DlgMngFile(CWnd* pParent /*=NULL*/)
	: CDialog(DlgMngFile::IDD, pParent)
	, h_module_(NULL)
	, p_base_(NULL)
	, p_mng_file_(NULL)
	, p_progress_show_(NULL)
{
	dlgp_main_ = static_cast<HRRpcCliDlg*>(pParent);
}


// --------------------------------------------------------
/// @brief		destructor
// --------------------------------------------------------
DlgMngFile::~DlgMngFile()
{
}


void DlgMngFile::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	DDX_Control(pDX, IDC_LIST_FILE_HI5, lcFileHi5_);
	DDX_Control(pDX, IDC_ED_PATH_RC, edPathRc_);
	DDX_Control(pDX, IDC_ED_FNAME_RC, edFNameRc_);
	DDX_Control(pDX, IDC_ED_FNAME_PC, edFNamePc_);
	DDX_Control(pDX, IDC_PROGRESS, progressCtrl_);
}


BEGIN_MESSAGE_MAP(DlgMngFile, CDialog)
	ON_WM_DESTROY()
	ON_BN_CLICKED(IDC_SEL_FNAME_PC, &DlgMngFile::OnBnClickedSelFnamePc)
	ON_BN_CLICKED(IDC_FLIST_HI5, &DlgMngFile::OnBnClickedFlistHi5)
	ON_BN_CLICKED(IDC_LOAD_FROM_HI5, &DlgMngFile::OnBnClickedLoadFromHi5)
	ON_BN_CLICKED(IDC_STORE_TO_HI5, &DlgMngFile::OnBnClickedStoreToHi5)
	ON_BN_CLICKED(IDC_DEL_HI5, &DlgMngFile::OnBnClickedDelHi5)
END_MESSAGE_MAP()


// --------------------------------------------------------
/// @return
///			- 0		success
///			- -1	error
/// @brief		Initialize HRRpcProxy - MngFile
// --------------------------------------------------------
int DlgMngFile::InitProxyMngFile()
{
	HRESULT		hr;

	// ------------------------------------------
	// Create COM component instances & get interface - IMngFile
	hr = CreateInstanceFromInst(h_module_, hr_rpc_proxy::CLSID_MngFile, hr_rpc_proxy::IID_IMngFile, (void**)&p_mng_file_);
	if(FAILED(hr)) {
		MessageBox(_T("Error in getting IMngFile."), 0, MB_OK | MB_ICONSTOP);
		return -1;
	}

	// bind the proxy base interface
	p_mng_file_->SetProxyBase(p_base_);


	return 0;
}


// --------------------------------------------------------
/// @return
///			- 0		success
/// @brief		End HRRpcProxy - MngFile
// --------------------------------------------------------
int DlgMngFile::EndProxyMngFile()
{
	if(p_mng_file_)
	{
		p_mng_file_->Release();
		p_mng_file_ = NULL;
	}

	return 0;
}


// DlgMngFile message handlers

// --------------------------------------------------------
/// @return		TRUE
/// @brief		initialize dialog
// --------------------------------------------------------
BOOL DlgMngFile::OnInitDialog()
{
	CDialog::OnInitDialog();

	// list control
	lcFileHi5_.InsertColumn(0, _T("filename"), LVCFMT_LEFT, 100, 0);
	lcFileHi5_.InsertColumn(1, _T("size"), LVCFMT_LEFT, 55, 1);		// The number of blocks (filesize)
	lcFileHi5_.InsertColumn(2, _T("date"), LVCFMT_LEFT, 78, 2);

	// create COM component instance & get interface
	InitProxyMngFile();

	// progress show
	p_progress_show_ = new ProgressShow(&progressCtrl_);

	// register progress object
	p_mng_file_->SetProgress(p_progress_show_);

	return TRUE;  // return TRUE unless you set the focus to a control
	// exception: OCX property page must return FALSE
}


// --------------------------------------------------------
/// @brief		handle destruction of dialog
// --------------------------------------------------------
void DlgMngFile::OnDestroy()
{
	CDialog::OnDestroy();

	delete p_progress_show_;

	EndProxyMngFile();
}


// --------------------------------------------------------
/// @brief		Open a file dialog and set the selected filename in Edit for PC filename
// --------------------------------------------------------
void DlgMngFile::OnBnClickedSelFnamePc()
{
	static TCHAR szFilter[] = _T("All Files (*.*)|*.*||");


	// file dialog
	CFileDialog		dlgFile(TRUE, NULL, NULL, 0, szFilter, this, 0);

	INT_PTR nResult = dlgFile.DoModal();
	if(nResult==IDCANCEL) return;

	// set the selected filename
	edFNamePc_.SetWindowText(dlgFile.GetPathName());
}


// --------------------------------------------------------
/// @brief		Enumerate remote controller's files, and fill the file ListCtrl.
// --------------------------------------------------------
void DlgMngFile::OnBnClickedFlistHi5()
{
	HRESULT	hr;
	int		i, iNFile, iSize;
	CString strPath;
	CString	strMsg, strSize;
	

	// path
	edPathRc_.GetWindowText(strPath);
	p_mng_file_->SetPath(_bstr_t(strPath));

	// call updating service
	hr = p_mng_file_->UpdateFileInfo();
	if(FAILED(hr)) {			// error
		if(dlgp_main_) {
			strMsg.Format(_T("%s (hr=%d)"), LoadString(IDS_MErrCommCheck), hr);
			dlgp_main_->LogToMonitor(strMsg + _T("\r\n"));
		}
		return;
	}

	// clear ListCtrl
	lcFileHi5_.DeleteAllItems();

	// Fill the file ListCtrl.
	p_mng_file_->GetNFileInfo(iNFile);
	for(i=0; i<iNFile; i++)
	{
		// (Caution: Don't reuse _bstr_t for BSTR output parameter. You have to dispatch it to free the memory.)
		_bstr_t	bsFName, bsDate, bsTime;

		// get each file info one by one.
		p_mng_file_->GetFileInfo(i, bsFName.GetBSTR(), iSize, bsDate.GetBSTR(), bsTime.GetBSTR());

		// file name
		lcFileHi5_.InsertItem(i, bsFName);

		// file size
		strSize.Format(_T("%d"), iSize);
		lcFileHi5_.SetItem(i, 1, LVIF_TEXT, strSize, 0, 0, 0, 0);
		
		// date
		lcFileHi5_.SetItem(i, 2, LVIF_TEXT, bsDate, 0, 0, 0, 0);
	}
}


// --------------------------------------------------------
/// @brief		Copy specified file from remote controller to local PC,
///				and display the output message. (Hi5 -> PC)
// --------------------------------------------------------
void DlgMngFile::OnBnClickedLoadFromHi5()
{
	if(p_mng_file_ == NULL) return;

	HRESULT	hr;
	CString strPath;
	CString strPathFNamePc, strPathFNameRc;
	CString strMsgWhole, strMsg;


	// file name
	edFNamePc_.GetWindowText(strPathFNamePc);	// local
	edFNameRc_.GetWindowText(strPathFNameRc);	// remote

	// path
	edPathRc_.GetWindowText(strPath);
	p_mng_file_->SetPath(_bstr_t(strPath));

	// call the service, success/failure message
	hr = p_mng_file_->ReadFile(_bstr_t(strPathFNameRc), _bstr_t(strPathFNamePc));
	if(hr==S_OK) {
		strMsg = LoadString(IDS_MTransferCompleted);
	}
	else {
		strMsg = hres2msg(hr);
	}

	// output message
	strMsgWhole.Format(_T("[%s] %s \r\n"), strPathFNameRc, strMsg);
	dlgp_main_->LogToMonitor(strMsgWhole);
}


// --------------------------------------------------------
/// @brief		Copy specified file from local PC to remote controller,
///				and display the output message. (Hi5 <- PC)
// --------------------------------------------------------
void DlgMngFile::OnBnClickedStoreToHi5()
{
	if(p_mng_file_ == NULL) return;

	HRESULT	hr;
	CString strPathFNamePc, strPathFNameRc;
	CString strMsgWhole, strMsg;


	// file name
	edFNamePc_.GetWindowText(strPathFNamePc);	// local
	edFNameRc_.GetWindowText(strPathFNameRc);	// remote

	// call the service, success/failure message
	hr = p_mng_file_->WriteFile(_bstr_t(strPathFNameRc), _bstr_t(strPathFNamePc));
	if(hr==S_OK) {
		strMsg = LoadString(IDS_MTransferCompleted);
	}
	else {
		strMsg = hres2msg(hr);
	}

	strMsgWhole += strMsg;
	strMsgWhole += _T("\r\n");

	// output message
	strMsgWhole.Format(_T("[%s] %s \r\n"), strPathFNameRc, strMsg);
	dlgp_main_->LogToMonitor(strMsgWhole);
}


// --------------------------------------------------------
/// @brief		Delete specified file of remote controller,
///				and display the output message. (Hi5 <- PC)
// --------------------------------------------------------
void DlgMngFile::OnBnClickedDelHi5()
{
	if(p_mng_file_ == NULL) return;

	HRESULT	hr;
	CString strPath;
	CString strFNameRc;
	CString strMsgWhole, strMsg;


	// file name
	edFNameRc_.GetWindowText(strFNameRc);	// remote

	// path
	edPathRc_.GetWindowText(strPath);
	p_mng_file_->SetPath(_bstr_t(strPath));

	// call the service, success/failure message
	hr = p_mng_file_->DeleteFile(_bstr_t(strFNameRc));
	if(hr==S_OK) {
		strMsg = LoadString(IDS_MDeleteCompleted);
	}
	else {
		strMsg = hres2msg(hr);
	}

	// output message
	strMsgWhole.Format(_T("[%s] %s \r\n"), strFNameRc, strMsg);
	dlgp_main_->LogToMonitor(strMsgWhole);
}
