﻿
// HRRpcCli.cpp : Defines the class behaviors for the application.
//

#include "stdafx.h"
#include "resource.h"
#include "../inc/IBase.h"
#include "../inc/IMngFile.h"
#include "../inc/ErrCodeRef.h"


// unnamed namespace (used only in this file)
namespace
{
	struct HResMsg
	{
		HRESULT		hr_;
		int			ids_;
	};

	/// @brief	map between HRESULT - IDS_
	HResMsg g_hres_ids_tbl[] =
	{
		{ MNG_FILE_E_FAIL_OPEN_LOCAL_FILE, IDS_FAIL_OPEN_LOCAL_FILE },
		{ BASE_E_COMM_NOT_CREATED, IDS_FAIL_OPEN_LOCAL_FILE },
		{ BASE_E_COMM_REQUEST, IDS_E_COMM_REQUEST },
		{ BASE_E_TIME_OUT_RESPONSE, IDS_E_TIME_OUT_RESPONSE },
		{ BASE_E_INVALID_SEGMENT, IDS_E_INVALID_SEGMENT },
		{ BASE_E_INVALID_DATA_SIZE, IDS_E_INVALID_DATA_SIZE },
		{ BASE_E_SERVICE, IDS_E_SERVICE },

		{ 0, 0 }	// end
	};

	/// @brief	map between error code - IDS_
	long g_errcode_ids_tbl[][2] =
	{
		{ ERR_FAIL_FIND_FILE, IDS_MFileNotFound },
		{ ERR_FAIL_CREATE_FILE, IDS_MFailCreateFile },
		{ ERR_FAIL_WRITE_MOTOR_ON, IDS_MNotExeMotorOn },
		{ ERR_FAIL_WRITE_FILE_PROTECT, IDS_MProtectedFile },
		{ ERR_FAIL_WRITE_MEM_PROTECT, IDS_MProtectedMem },
		{ ERR_FAIL_WRITE_PLAYING, IDS_MCantWritePlaying },
		{ ERR_NOT_SUPPORTED_FILE_TYPE, IDS_MUnsupportedFileType },
		{ ERR_ALREADY_EXIST, IDS_MFailAlreadyExist },
		{ ERR_FAIL_OPEN_FILE, IDS_MErrOpenFile },
		{ ERR_FILE_BLOCK_DAMAGED, IDS_MFileSystemDamaged },

		{ ERR_UNDEFINED_UCRD, IDS_MUndefUCrd },
		{ ERR_UCRD_NO_UNSET, IDS_MUCrdNoUnset },

		{ ERR_FAIL_WRITE, 0 },


		{ 0, 0 }	// end
	};

}; // unnamed namespace


// --------------------------------------------------------
/// @param[in]	hr		HRESULT value to convert
/// @return		message string
/// @brief		convert HRESULT(FACILITY_ITF) into message string
// --------------------------------------------------------
CString hres2msg_itf(HRESULT hr)
{
	HResMsg		hresMsg;
	long		i;
	CString		strMsg;

	for(i=0; ; i++)
	{
		hresMsg = g_hres_ids_tbl[i];
		if(hresMsg.hr_==0) return _T("");		// can't find
		if(hr==hresMsg.hr_) {
			strMsg.LoadString(hresMsg.ids_);
			return strMsg;
		}
	};
}


// --------------------------------------------------------
/// @param[in]	hr		return value of COM method
/// @return		error message
/// @brief		Get hr's error message string
// --------------------------------------------------------
CString hres2msg(HRESULT hr)
{
	CString	strMsg;
	void* pMsgBuf;


	// FACILITY_ITF
	strMsg = hres2msg_itf(hr);
	if(strMsg.IsEmpty()==FALSE) return strMsg;

	// others
	::FormatMessage(
		FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM,
		NULL,
		hr,
		MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
		(LPTSTR)&pMsgBuf,
		0,
		NULL);

	strMsg.Format(_T("%s\r\nhr=0x%x"), pMsgBuf, hr);
	
	LocalFree(pMsgBuf);

	return strMsg;
}


// --------------------------------------------------------
/// @param[in]	iErrCode	HR-RPC service error code
/// @return		error message string
/// @brief		Get error message string from HR-RPC service error code
// --------------------------------------------------------
CString errcode2msg(int iErrCode)
{
	long	l, lERR;
	CString		strMsg;

	for(l=0; ; l++)
	{
		lERR = g_errcode_ids_tbl[l][0];
		if(lERR==0) return 0;		// can't find
		if(iErrCode==lERR) {
			strMsg.LoadString(g_errcode_ids_tbl[l][1]);
			return strMsg;
		}
	};
}
