﻿// filename : Loose_COM.cpp
// 
/// @author Choi, Won-Hyuk, Hyundai Heavy Industries Co., Ltd.
/// @section CREATEINFO
///  Creator	: Hyundai Heavy Industries Co., Ltd.
/// @date 2015-03-31


#include "stdafx.h"
#include <windows.h>


HRESULT (STDAPICALLTYPE *fpDllGetClassObject)(const CLSID&, const IID&, void**)=0;

// --------------------------------------------------------
/// @param[in]	hInst		COM module(DLL)'s instance handle
/// @param[in]	clsid		COM component의 CLSID
/// @param[in]	iid			COM interface의 IID
/// @param[out]	ppv			pointer for getting the COM interface pointer
/// @return		HRESULT
/// @brief		Substitute CoCreateInstance() function.
///				It gets the COM interface by not using registry information but loading DLL directly.
///				CoInitialize(), CoUninitialize() are not needed.
///				Instead, when using COM object is completed, you have to call DLL's FreeLibrary() on your own.
// --------------------------------------------------------
HRESULT CreateInstanceFromInst(HINSTANCE hInst, const CLSID& clsid, const IID& iid, void** ppv)
{
	HRESULT		hr;

#if 0	// create an instance of registered-COM component
	hr = ::CoCreateInstance(clsid, NULL, CLSCTX_INPROC_SERVER, iid, ppv);

#else	// create an instance of unregistered-COM component
	const char*		cp_func_name="DllGetClassObject";
	DWORD			dwErrCode;
	IClassFactory*	pIFactory = NULL;

	// get export function addresses
	fpDllGetClassObject = (HRESULT(STDAPICALLTYPE*)(const CLSID&, const IID&, void**))GetProcAddress(hInst, cp_func_name);
	if(fpDllGetClassObject==NULL)
	{
		dwErrCode = GetLastError();
		return HRESULT_FROM_WIN32(dwErrCode);
	}

	// get class factory
	hr = fpDllGetClassObject(clsid, IID_IClassFactory, (void**)&pIFactory);
	if(SUCCEEDED(hr))
	{
		// create component (no aggregation)
		hr = pIFactory->CreateInstance(NULL, iid, ppv);

		// release the class factory
		pIFactory->Release();
	}
#endif

	return hr;
}
