﻿/// @file		ErrCodeRef.h
/// @brief		error code of HR-RPC service. (excerpt from Hi5a V40.11-xx)
/// @author		Choi, Won-Hyuk, Hyundai Heavy Industries Co., Ltd.
/// @date		2016-05-10

#pragma once


#define ERR_BASE					-0x100000


///////////////////////////////////////////////////////////
// general message & error		MSG_GEN_BASE + (-1 ~ -9999)
#define MSG_GEN_BASE				(ERR_BASE - 0x10000)

#define MSG_NO_CHANGE				(MSG_GEN_BASE - 0x10)
#define MSG_EVENT					(MSG_GEN_BASE - 0x20)
#define MSG_NO_EVENT				(MSG_GEN_BASE - 0x30)
#define MSG_EXMARK					(MSG_GEN_BASE - 0x40)
#define MSG_EXE_COMPLETE			(MSG_GEN_BASE - 0x50)
#define MSG_INTERNAL_PROG			(MSG_GEN_BASE - 0x60)
#define MSG_EXTERNAL_PROG			(MSG_GEN_BASE - 0x70)
#define MSG_INTERNAL_START			(MSG_GEN_BASE - 0x80)
#define MSG_EXTERNAL_START			(MSG_GEN_BASE - 0x90)
#define ERR_VALID_TEACH_1STEP		(MSG_GEN_BASE - 0xA0)
#define ERR_INVALID_PLAYBACK_MODE	(MSG_GEN_BASE - 0xB0)
#define ERR_INVALID_TEACH_MODE		(MSG_GEN_BASE - 0xC0)
#define ERR_FAIL_GET_HANDLE			(MSG_GEN_BASE - 0xD0)
#define ERR_NOT_FIND_CMD			(MSG_GEN_BASE - 0xE0)
#define MSG_CANCELED				(MSG_GEN_BASE - 0xF0)
#define MSG_RESTORED				(MSG_GEN_BASE - 0x100)


///////////////////////////////////////////////////////////
// data error	ERR_DATA_BASE + (-1 ~ -9999)
#define ERR_DATA_BASE				(ERR_BASE - 0x20000)

#define ERR_INVALID_REGION			(ERR_DATA_BASE - 0x10)
#define ERR_ACCESS_DENIED			(ERR_DATA_BASE - 0x20)
#define ERR_DATA_NOT_EXIST			(ERR_DATA_BASE - 0x30)
#define ERR_OVERFLOW				(ERR_DATA_BASE - 0x40)
#define ERR_RESOURCE_LOCKED			(ERR_DATA_BASE - 0x50)
#define ERR_SELF_DIAG_NOT_COMPLETED	(ERR_DATA_BASE - 0x60)


///////////////////////////////////////////////////////////
// file error	ERR_FILE_BASE + (-1 ~ -9999)
#define ERR_FILE_BASE				(ERR_BASE - 0x30000)

#define ERR_FAIL_FIND_FILE			(ERR_FILE_BASE - 0x10)
#define ERR_FAIL_FIND_PROGRAM		(ERR_FILE_BASE - 0x15)
#define ERR_FAIL_WRITE_MEM_PROTECT	(ERR_FILE_BASE - 0x20)
#define ERR_FAIL_WRITE_FILE_PROTECT	(ERR_FILE_BASE - 0x25)
#define ERR_FAIL_WRITE_MOTOR_ON		(ERR_FILE_BASE - 0x27)
#define ERR_FAIL_WRITE_PLAYING		(ERR_FILE_BASE - 0x28)
#define ERR_FAIL_WRITE				(ERR_FILE_BASE - 0x30)
#define ERR_FAIL_WRITE_FILE_ROBOT	(ERR_FILE_BASE - 0x31)
#define ERR_ALREADY_EXIST			(ERR_FILE_BASE - 0x40)
#define ERR_FAIL_CREATE_FILE		(ERR_FILE_BASE - 0x50)
#define ERR_FAIL_OPEN_FILE			(ERR_FILE_BASE - 0x55)
#define ERR_INVALID_POS				(ERR_FILE_BASE - 0x60)
#define ERR_GET_HIDDEN_POSE			(ERR_FILE_BASE - 0x61)
#define ERR_INVALID_FORMAT			(ERR_FILE_BASE - 0x65)
#define ERR_END_OF_FILE				(ERR_FILE_BASE - 0x70)
#define ERR_FAIL_RELIVE_BLOCK		(ERR_FILE_BASE - 0x80)
#define ERR_MEM_DAMAGE_NEED_FORMAT	(ERR_FILE_BASE - 0x90)
#define ERR_NOT_SUPPORTED_ENTRY		(ERR_FILE_BASE - 0xA0)
#define ERR_NOT_SUPPORTED_FILE_TYPE	(ERR_FILE_BASE - 0xA5)
#define ERR_NO_VACANT_TEMPFILE_NO	(ERR_FILE_BASE - 0xB0)
#define ERR_FAIL_INS_AUX_STMT		(ERR_FILE_BASE - 0xC0)
#define ERR_FAIL_COPY				(ERR_FILE_BASE - 0xC8)
#define ERR_FAIL_APPLY				(ERR_FILE_BASE - 0xCB)
#define ERR_FAIL_DELETE				(ERR_FILE_BASE - 0xD0)
#define ERR_EMPTY_FILE					(ERR_FILE_BASE - 0xE0)
#define ERR_NOT_CONSTFILE_NEED_FORMAT	(ERR_FILE_BASE - 0xF0)
#define ERR_FILEDIR_FULL				(ERR_FILE_BASE - 0x100)
#define ERR_LACKED_FILE_BLOCK			(ERR_FILE_BASE - 0x110)
#define ERR_SYS_BLANKBLOCK_FAIL		(ERR_FILE_BASE - 0x120)
#define ERR_OLDFILE_DEL_FAIL			(ERR_FILE_BASE - 0x130)
#define ERR_FAIL_GET_POINTER			(ERR_FILE_BASE - 0x140)
#define ERR_NOT_DEFINED_FILE			(ERR_FILE_BASE - 0x150)
#define ERR_DEL_HOME_POSI_DATA			(ERR_FILE_BASE - 0x160)
#define ERR_FILE_BLOCK_DAMAGED			(ERR_FILE_BASE - 0x170)
#define ERR_SRCFILE_NOT_FOUND			(ERR_FILE_BASE - 0x180)
#define ERR_TARGET_FILE_EXIST			(ERR_FILE_BASE - 0x190)
#define ERR_CMOV_MODIFY_INVALID			(ERR_FILE_BASE - 0x1A0)

#define ERR_GUN_NO_NOT_MATCHED			(ERR_FILE_BASE - 0x1B0)
#define ERR_FILE_NOT_FOUND				(ERR_FILE_BASE - 0x1C0)

#define ERR_STEP_NOT_FOUND				(ERR_FILE_BASE - 0x1E0)
#define ERR_N_AXES_NOT_MATCHED			(ERR_FILE_BASE - 0x200)
#define ERR_UNDEFINED_CRD				(ERR_FILE_BASE - 0x210)
#define ERR_LACK_OF_STEP_NO				(ERR_FILE_BASE - 0x220)
#define ERR_PROGRAM_DATA				(ERR_FILE_BASE - 0x230)
#define ERR_CONFIRM_ADDAXIS_SPEC		(ERR_FILE_BASE - 0x240)
#define ERR_RANGE_OVER					(ERR_FILE_BASE - 0x250)
#define ERR_NULL_POINTER				(ERR_FILE_BASE - 0x260)
#define ERR_CON_NULL_POINTER			(ERR_FILE_BASE - 0x261)
#define ERR_MCH_NULL_POINTER			(ERR_FILE_BASE - 0x262)
#define ERR_SWD_NULL_POINTER			(ERR_FILE_BASE - 0x263)
#define ERR_PNT_NULL_POINTER			(ERR_FILE_BASE - 0x264)
#define ERR_PAL_NULL_POINTER			(ERR_FILE_BASE - 0x265)
#define ERR_AAS_NULL_POINTER			(ERR_FILE_BASE - 0x266)
#define ERR_AAE_NULL_POINTER			(ERR_FILE_BASE - 0x267)
#define ERR_AAU_NULL_POINTER			(ERR_FILE_BASE - 0x268)
#define ERR_WEV_NULL_POINTER			(ERR_FILE_BASE - 0x269)
#define ERR_AAP_NULL_POINTER			(ERR_FILE_BASE - 0x26A)
#define ERR_FBU_NULL_POINTER			(ERR_FILE_BASE - 0x26B)
#define ERR_ADC_NULL_POINTER			(ERR_FILE_BASE - 0x26C)
#define ERR_ADP_NULL_POINTER			(ERR_FILE_BASE - 0x26D)
#define ERR_AGP_NULL_POINTER			(ERR_FILE_BASE - 0x26E)
#define ERR_AVC_NULL_POINTER			(ERR_FILE_BASE - 0x26F)
#define ERR_EFB_NULL_POINTER			(ERR_FILE_BASE - 0x270)
#define ERR_CLB_NULL_POINTER			(ERR_FILE_BASE - 0x271)
#define ERR_CLG_NULL_POINTER			(ERR_FILE_BASE - 0x272)
#define ERR_SAF_NULL_POINTER			(ERR_FILE_BASE - 0x273)
#define ERR_SWI_NULL_POINTER			(ERR_FILE_BASE - 0x274)
#define ERR_PROG_DATA_FAULT				(ERR_FILE_BASE - 0x280)

///////////////////////////////////////////////////////////
// network error	ERR_NET_BASE + (-1 ~ -9999)
#define ERR_NET_BASE				(ERR_BASE - 0x40000)

#define ERR_NOT_SUPPORTED_SERVICE	(ERR_NET_BASE - 0x10)
#define ERR_NOT_SUPPORTED_OPTION	(ERR_NET_BASE - 0x20)
#define ERR_EXCESS_FRAME_SIZE		(ERR_NET_BASE - 0x30)
#define ERR_TIME_OUT				(ERR_NET_BASE - 0x40)
#define ERR_EXCESS_RETRY_LIMIT		(ERR_NET_BASE - 0x50)
#define ERR_EXCESS_N_ELEM			(ERR_NET_BASE - 0x60)
#define ERR_EXCESS_PARAM_LIMIT		(ERR_NET_BASE - 0x70)
#define ERR_INVALID_PARAM			(ERR_NET_BASE - 0x80)
#define ERR_CONT_NEXT_CYCLE			(ERR_NET_BASE - 0xA0)


///////////////////////////////////////////////////////////
// language error	ERR_LANG_BASE + (-1 ~ -9999)
#define ERR_LANG_BASE				(ERR_BASE - 0x50000)

#define ERR_INVALID_SYNTAX			(ERR_LANG_BASE - 0x10)
#define ERR_INVALID_5_COLUMN		(ERR_LANG_BASE - 0x25)
#define ERR_UCRD_NO_UNSET			(ERR_LANG_BASE - 0x30)
#define ERR_DUP_RECORD				(ERR_LANG_BASE - 0x40)
#define ERR_NO_HID_POSE				(ERR_LANG_BASE - 0x50)
#define ERR_TOOL_MISMATCH			(ERR_LANG_BASE - 0x60)
#define ERR_GET_N_TOOL				(ERR_LANG_BASE - 0x70)
#define ERR_UNDEFINED_ID			(ERR_LANG_BASE - 0x80)
#define ERR_FAIL_READ_VARIABLE		(ERR_LANG_BASE - 0xA0)
#define ERR_FAIL_WRITE_VARIABLE		(ERR_LANG_BASE - 0xB0)
#define ERR_EXCEED_TYPE_RANGE		(ERR_LANG_BASE - 0x100)


///////////////////////////////////////////////////////////
// motion or kinematix error	ERR_MOT_BASE + (-1 ~ -9999)
#define ERR_MOT_BASE					(ERR_BASE - 0x60000)
#define ERR_WORKSPACE_OVER				(ERR_MOT_BASE - 0x10)
#define ERR_WORKSPACE_OVER_Ref_A_IK1	(ERR_MOT_BASE - 0x11)
#define ERR_WORKSPACE_OVER_Ref_A_IK2	(ERR_MOT_BASE - 0x12)
#define ERR_WORKSPACE_OVER_Ref_A_IK3	(ERR_MOT_BASE - 0x13)
#define ERR_WORKSPACE_OVER_Ref_N_IK1	(ERR_MOT_BASE - 0x14)
#define ERR_WORKSPACE_OVER_Ref_N_IK2	(ERR_MOT_BASE - 0x15)
#define ERR_WORKSPACE_OVER_Ref_N_IK3	(ERR_MOT_BASE - 0x16)
#define ERR_WORKSPACE_OVER_Ref_N_NSR	(ERR_MOT_BASE - 0x17)
#define ERR_WORKSPACE_OVER_Ref_N_NSR2	(ERR_MOT_BASE - 0x18)
#define ERR_WORKSPACE_OVER_Ref_N_INTR	(ERR_MOT_BASE - 0x19)
#define ERR_WORKSPACE_OVER_Ref_N_SNGR	(ERR_MOT_BASE - 0x20)

#define ERR_WORKSPACE_OVER_Cf_A_IK1		(ERR_MOT_BASE - 0x21)
#define ERR_WORKSPACE_OVER_Cf_A_IK2		(ERR_MOT_BASE - 0x22)
#define ERR_WORKSPACE_OVER_Cf_A_IK3		(ERR_MOT_BASE - 0x23)
#define ERR_WORKSPACE_OVER_Cf_A_AB		(ERR_MOT_BASE - 0x24)
#define ERR_WORKSPACE_OVER_Cf_A_Fp		(ERR_MOT_BASE - 0x25)
#define ERR_WORKSPACE_OVER_Cf_A_B		(ERR_MOT_BASE - 0x26)
#define ERR_WORKSPACE_OVER_Cf_N_NSR		(ERR_MOT_BASE - 0x27)
#define ERR_WORKSPACE_OVER_Cf_N_NSR2	(ERR_MOT_BASE - 0x28)
#define ERR_WORKSPACE_OVER_Cf_N_INTR	(ERR_MOT_BASE - 0x29)
#define ERR_WORKSPACE_OVER_Cf_N_SNGR	(ERR_MOT_BASE - 0x30)


#define ERR_POSE_MUST_SET_TO_UCRD	(ERR_MOT_BASE - 0x100)
#define ERR_UNDEFINED_UCRD			(ERR_MOT_BASE - 0x110) 
#define ERR_FAIL_DURING_PLAYBACK	(ERR_MOT_BASE - 0x120)
#define ERR_ENC_CAL_WITHOUT_MOTOR_ON	(ERR_MOT_BASE - 0x111)
#define ERR_NOT_USE_ROBOT_RUNNING	(ERR_MOT_BASE - 0x112)
#define ERR_EXCESS_MAX_SPEED		(ERR_MOT_BASE - 0x113)
#define ERR_FAIL_EXE_MOTORON		(ERR_MOT_BASE - 0x114)
#define ERR_DISABLE_REL_WAIT		(ERR_MOT_BASE - 0x115)
#define ERR_INVALID_IN_INTFUN_ON	(ERR_MOT_BASE - 0x116)
#define ERR_FAIL_EXE_MOTOROFF		(ERR_MOT_BASE - 0x117)
#define ERR_FAIL_EXE_AUTOMODE		(ERR_MOT_BASE - 0x118)
#define ERR_SOFTLIMIT_OVER			(ERR_MOT_BASE - 0x150)
#define ERR_SHIFTLIMIT_OVER			(ERR_MOT_BASE - 0x160)


///////////////////////////////////////////////////////////
// application error			ERR_APPL_BASE + (-1 ~ -9999)
#define ERR_APPL_BASE				(ERR_BASE - 0x70000)

#define ERR_NOT_APPL_MODE_ARCWELD	(ERR_APPL_BASE - 0x20)
#define ERR_INVALID_PATTERN_NO		(ERR_APPL_BASE - 0x30)
#define ERR_REMAKING_SQUEEZE_FORCE	(ERR_APPL_BASE - 0x40)
#define ERR_INVALID_SERVOGUN_CHNG	(ERR_APPL_BASE - 0x50)
#define ERR_EXCEED_SQUEEZE_FORCE	(ERR_APPL_BASE - 0x60)
#define ERR_CAN_SLAVE_ONLY			(ERR_APPL_BASE - 0x70)
#define ERR_SPOTWLED_ONLY			(ERR_APPL_BASE - 0x80)
#define ERR_CNAT_SUPPORTED_GUN		(ERR_APPL_BASE - 0x90)
#define ERR_NOT_COMMON_COORDI		(ERR_APPL_BASE - 0xA0)
#define ERR_PALLETIZE_ONLY			(ERR_APPL_BASE - 0xB0)
#define ERR_CNVYSYNC_ONLY			(ERR_APPL_BASE - 0xC0)
#define ERR_NOT_EXE_CNVYSIM			(ERR_APPL_BASE - 0xD0)
#define ERR_NOT_SERVOGUNCHNG_ONLY	(ERR_APPL_BASE - 0xE0)
#define ERR_VALID_SERVOGUN_ONLY		(ERR_APPL_BASE - 0xF0)
#define ERR_VALID_SERVOHAND_ONLY	(ERR_APPL_BASE - 0x110)
#define ERR_VALID_EQUALGUN_ONLY		(ERR_APPL_BASE - 0x120)
#define ERR_NOT_SERVOGUN_AXIS		(ERR_APPL_BASE - 0x130)
#define ERR_FAIL_SELECT_GUN			(ERR_APPL_BASE - 0x140)
#define ERR_DUPLICATED_MASTER		(ERR_APPL_BASE - 0x150)
#define ERR_NOT_READY_COOPER_STATUS	(ERR_APPL_BASE - 0x160)
#define ERR_MISMATCH_MASTER_SLAVE	(ERR_APPL_BASE - 0x170)
#define ERR_RANGE_OVER_POSITION		(ERR_APPL_BASE - 0x180)
#define ERR_EXCEED_CURRENT_LIMIT	(ERR_APPL_BASE - 0x190)
#define ERR_EXCEED_OVERLOAD_LEVEL	(ERR_APPL_BASE - 0x200)
#define ERR_PANEL_THICK_IS_MINUS	(ERR_APPL_BASE - 0x210)
#define ERR_NOT_SETUP_PANEL_THICK	(ERR_APPL_BASE - 0x220)
#define ERR_EXCESS_ALLOWED_PANEL_THICK	(ERR_APPL_BASE - 0x230)
#define ERR_INVERSE_KINEMATIC_CAL	(ERR_APPL_BASE - 0x240)
#define ERR_SRC_PROG_NOT_EXIST		(ERR_APPL_BASE - 0x250)
#define ERR_DST_PROG_NOT_EXIST		(ERR_APPL_BASE - 0x260)
#define ERR_START_OVER_END_STEP		(ERR_APPL_BASE - 0x270)
#define ERR_NOT_EXIST_INSERT_STEP	(ERR_APPL_BASE - 0x280)
#define ERR_PROG_PROTECTED			(ERR_APPL_BASE - 0x290)
#define ERR_AXIS_NO_NOT_MATCH		(ERR_APPL_BASE - 0x2A0)
#define ERR_FILE_COPY				(ERR_APPL_BASE - 0x2B0)
#define ERR_FILE_NOT_EXIST			(ERR_APPL_BASE - 0x2C0)
#define ERR_START_STEP_ERROR		(ERR_APPL_BASE - 0x2D0)
#define ERR_END_STEP_ERROR			(ERR_APPL_BASE - 0x2E0)
#define ERR_DATA_RANGE_OVER			(ERR_APPL_BASE - 0x2F0)
#define ERR_SELECT_STEP				(ERR_APPL_BASE - 0x300)
#define ERR_CANNOT_SUPPORT_REFP_STEP (ERR_APPL_BASE - 0x310)
#define ERR_CANNOT_STEP_FETCH		(ERR_APPL_BASE - 0x320)
#define ERR_SVG_AUTO_TUNNING_EXECUTING	(ERR_APPL_BASE - 0x330)
#define ERR_START_PRESSURE_OVER_CURRENT	(ERR_APPL_BASE - 0x340)
#define ERR_SVTOOL_DISCONNECTED		(ERR_APPL_BASE - 0x350)
#define ERR_GUNSEA_NOT_COMPLETED	(ERR_APPL_BASE - 0x360)
#define ERR_CNVY_PULSE_NOT_CHANGED	(ERR_APPL_BASE - 0x370)
#define ERR_TWO_POINT_IS_CLOSE		(ERR_APPL_BASE - 0x380)
#define ERR_NOT_SUPPORT_ROBOT		(ERR_APPL_BASE - 0x390)
#define ERR_REC_POSE_TOO_NEAR		(ERR_APPL_BASE - 0x3A0)
#define ERR_NOT_DEFINED_CRD_NO		(ERR_APPL_BASE - 0x3B0)
#define ERR_CLOSE_THREE_POINT		(ERR_APPL_BASE - 0x3C0)
#define ERR_LINEAR_THREE_POINT		(ERR_APPL_BASE - 0x3D0)
#define ERR_CALIB_EXE_ERROR			(ERR_APPL_BASE - 0x3E0)
#define ERR_RECORD_TO_EQUAL_UCRD	(ERR_APPL_BASE - 0x3F0)
#define ERR_PROG_IS_NOT_HIDDEN_POSE	(ERR_APPL_BASE - 0x400)
#define ERR_CAL_RESULT_WAS_OVER_5MM	(ERR_APPL_BASE - 0x410)
#define ERR_COORD_TRANSFER			(ERR_APPL_BASE - 0x420)
#define ERR_FIX_ADD_AXIS_POSE		(ERR_APPL_BASE - 0x430)
#define ERR_NOT_USE_UCRD_STEP		(ERR_APPL_BASE - 0x440)
#define ERR_CAN_NOT_CONVERSION		(ERR_APPL_BASE - 0x450)
#define ERR_FAIL_GET_BLOCK			(ERR_APPL_BASE - 0x460)
#define ERR_AUTO_CNST_EXE			(ERR_APPL_BASE - 0x470)
#define ERR_POSI_GROUP_AXIS_OVER	(ERR_APPL_BASE - 0x480)
#define ERR_POSI_CALIB_EXE			(ERR_APPL_BASE - 0x490)
#define ERR_NOT_EXIST_STEP			(ERR_APPL_BASE - 0x4A0)
#define ERR_DIST_STEPS				(ERR_APPL_BASE - 0x4B0)
#define ERR_NOT_READY_DRIVING		(ERR_APPL_BASE - 0x4C0)
#define ERR_ASSIGN_TEMP_FILE		(ERR_APPL_BASE - 0x4D0)
#define ERR_MODIFY_STEP_NO			(ERR_APPL_BASE - 0x4E0)
#define ERR_EQUAL_SRC_AND_DST_PROG	(ERR_APPL_BASE - 0x4F0)
#define ERR_POSE_CONVERSION			(ERR_APPL_BASE - 0x500)
#define ERR_MOTION_INIT				(ERR_APPL_BASE - 0x510)
#define ERR_ENCODER_RESET			(ERR_APPL_BASE - 0x520)
#define ERR_SPOT_WELD_CND			(ERR_APPL_BASE - 0x530)
#define ERR_SPOT_WELD_SEQ			(ERR_APPL_BASE - 0x540)
#define ERR_MAN_SET_INERTIA_CENTER	(ERR_APPL_BASE - 0x550)
#define ERR_MAN_SET_Z_INERTIA_CENTER	(ERR_APPL_BASE - 0x560)
#define ERR_MAN_SET_XY_INERTIA_CENTER	(ERR_APPL_BASE - 0x570)
#define ERR_MAN_SET_Z_INERTIA		(ERR_APPL_BASE - 0x580)
#define ERR_MAN_SET_XYZ_INERTIA		(ERR_APPL_BASE - 0x590)
#define ERR_V_ANGLE_WAS_OVER		(ERR_APPL_BASE - 0x5F0)
#define ERR_FORCECRTL_DISABLE		(ERR_APPL_BASE - 0x600)

#define ERR_SPOTGUN_RANGE_OVER		(ERR_APPL_BASE - 0x601)
#define ERR_SVTOOLCHG_RANGE_OVER	(ERR_APPL_BASE - 0x602)
#define ERR_TOOL_RANGE_OVER			(ERR_APPL_BASE - 0x603)
#define ERR_PEDTOOL_RANGE_OVER		(ERR_APPL_BASE - 0x604)
#define ERR_GUN_NO_NOT_EXIST		(ERR_APPL_BASE - 0x605)

#define ERR_BASEAXIS_LOCKED			(ERR_APPL_BASE - 0x610)


///////////////////////////////////////////////////////////
// device error				ERR_APPL_BASE + (-1 ~ -9999)
#define ERR_DEV_BASE				(ERR_BASE - 0x80000)

#define ERR_DEV_NOT_REPLY			(ERR_DEV_BASE - 0x10)
#define ERR_DEV_INCORRECT_DATA		(ERR_DEV_BASE - 0x20)
#define ERR_DEV_INCORRECT_ID		(ERR_DEV_BASE - 0x30)
#define ERR_DEV_INVALID_ID			(ERR_DEV_BASE - 0x40)


